searchData={"items":[{"type":"module","title":"CozyProxy","doc":"Proxy requests to other plugs.","ref":"CozyProxy.html"},{"type":"module","title":"Usage - CozyProxy","doc":"A `CozyProxy` instance is an isolated supervision tree and you can include it in\napplication's supervisor:\n\n    # lib/demo/application.ex\n    def start(_type, _args) do\n      children = [\n        # ...\n        {CozyProxy, Application.fetch_env!(:demo, CozyProxy)}\n      ]\n\n      opts = [strategy: :one_for_one, name: Demo.Supervisor]\n      Supervisor.start_link(children, opts)\n    end\n\nAbove code requires a piece of configuration:\n\n    config :demo, CozyProxy,\n      server: true,\n      adapter: Plug.Cowboy,\n      scheme: :http,\n      ip: {127, 0, 0, 1},\n      port: 4000,\n      backends: [\n        %{\n          plug: HealthCheckPlug,\n          path: \"/health-check\"\n        },\n        %{\n          plug: DemoWebAPI.Endpoint,\n          path: \"/api\"\n        },\n        %{\n          plug: DemoAdminWeb.Endpoint,\n          path: \"/admin\"\n        },\n        %{\n          plug: DemoWeb.Endpoint,\n          path: \"/\"\n        }\n      ]\n\nWhen using `CozyProxy` with Phoenix endpoints, it's required to configure\nthe path of endpoints to a proper value. And it's better to configure\n`:server` option of endpoints to `false`, which avoids them serving requests\nbypassing `CozyProxy`. For example:\n\n    config :demo, DemoWeb.Endpoint,\n      url: [path: \"/\"],\n      server: false\n\n    config :demo, DemoWebAPI.Endpoint,\n      url: [path: \"/api\"],\n      server: false\n\n    config :demo, DemoAdminWeb.Endpoint,\n      url: [path: \"/admin\"],\n      server: false","ref":"CozyProxy.html#module-usage"},{"type":"module","title":"Options - CozyProxy","doc":"* `:server` - start the web server or not. Default to `false`. It is aware\n    of Phoenix startup arguments, if the application is started with\n    `mix phx.server` or `iex -S mix phx.server`, this option will set\n    to `true`.\n  * `:backends` - the list of backends. Default to `[]`. See following section for\n    more details.\n  * `:adapter` - the adapter for web server, `Plug.Cowboy` and `Bandit` are\n    available. Default to `Plug.Cowboy`.\n  * adapter options - all other options will be put into an keyword list and\n    passed as the options of the adapter. See following section for more details.","ref":"CozyProxy.html#module-options"},{"type":"module","title":"About `:backends` - CozyProxy","doc":"A valid `:backends` option is a list of maps, and the keys of maps are:\n\n  * `:plug`:\n    * required\n    * typespec: `module() | {module(), keyword()}`\n    * examples:\n      * `HealthCheckPlug`\n      * `{HealthCheckPlug, []}`\n      * ...\n  * `:method`:\n    * optional\n    * typespec: `String.t()`\n    * examples:\n      * `\"GET\"`\n      * `\"POST\"`\n      * ...\n  * `:host`:\n    * optional\n    * typespec: `String.t()` | `Regex.t()`\n    * examples:\n      * `\"example.com\"`\n      * ...\n  * `:path`:\n    * optional\n    * typespec: `String.t()`\n    * examples:\n      * `\"/admin\"`\n      * `\"/api\"`\n      * ...\n  * `:rewrite_path_info`:\n    * optional\n    * typespec: `boolean()`\n    * default: `true`\n    * examples:\n      * `true`\n      * `false`","ref":"CozyProxy.html#module-about-backends"},{"type":"module","title":"The order of backends matters - CozyProxy","doc":"If you configure the backends like this:\n\n    config :demo, CozyProxy,\n      backends: [\n        %{\n          plug: DemoUserWeb.Endpoint,\n          path: \"/\"\n        },\n        %{\n          plug: DemoUserAPI.Endpoint,\n          path: \"/api\"\n        },\n        %{\n          plug: DemoAdminWeb.Endpoint,\n          path: \"/admin\"\n        },\n        %{\n          plug: HealthCheck,\n          path: \"/health\"\n        }\n      ]\n\nThe first backend will always match, which may not what you expected.\n\nIf you want all backends to have a chance to match, you should configure them like this:\n\n    config :demo, CozyProxy,\n      backends: [\n        %{\n          plug: HealthCheck,\n          path: \"/health\"\n        },\n        %{\n          plug: DemoUserAPI.Endpoint,\n          path: \"/api\"\n        },\n        %{\n          plug: DemoAdminWeb.Endpoint,\n          path: \"/admin\"\n        },\n        %{\n          plug: DemoUserWeb.Endpoint,\n          path: \"/\"\n        }\n      ]","ref":"CozyProxy.html#module-the-order-of-backends-matters"},{"type":"module","title":"About adapter options - CozyProxy","doc":"In the section of Options, we said:\n\n> all other options will be put into an keyword list and passed as the options of the adapter.\n\nIt means the all options except `:server`, `:backends`, `:adapter` will be passed as the\nthe options of an adapter.\n\nTake `Plug.Cowboy` adapter as an example. If we declare the options like:\n\n    config :demo, CozyProxy,\n      backends: [\n        # ...\n      ],\n      adapter: Plug.Cowboy,\n      scheme: :http,\n      ip: {127, 0, 0, 1},\n      port: 4000,\n      transport_options: [num_acceptors: 2]\n\nThen following options will be passed to `Plug.Cowboy` when initializing CozyProxy:\n\n    [\n      scheme: :http,\n      ip: {127, 0, 0, 1},\n      port: 4000,\n      transport_options: [num_acceptors: 2]\n    ]\n\nFor more available adapter options:\n\n  * `Plug.Cowboy` - checkout [Plug.Cowboy options](https://hexdocs.pm/plug_cowboy/Plug.Cowboy.html#module-options).\n  * `Bandit` - checkout [Bandit options](https://hexdocs.pm/bandit/Bandit.html#t:options/0).","ref":"CozyProxy.html#module-about-adapter-options"},{"type":"function","title":"CozyProxy.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"CozyProxy.html#child_spec/1"},{"type":"function","title":"CozyProxy.start_link/2","doc":"","ref":"CozyProxy.html#start_link/2"},{"type":"extras","title":"CozyProxy","doc":"# CozyProxy\n\n[![CI](https://github.com/cozy-elixir/cozy_proxy/actions/workflows/ci.yml/badge.svg)](https://github.com/cozy-elixir/cozy_proxy/actions/workflows/ci.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/cozy_proxy.svg)](https://hex.pm/packages/cozy_proxy)\n\n> Proxy requests to other plugs.","ref":"readme.html"},{"type":"extras","title":"Features - CozyProxy","doc":"- Multiple adatpers support: `Plug.Cowboy` / `Bandit`\n- General plug support\n- WebSocket support (requires [`Plug >= 1.14`](https://github.com/elixir-plug/plug/blob/2ef07cdd2732cde5cac73fc39b49fe83d5fcc369/README.md?plain=1#L71))\n- Phoenix Endpoint support (requires [`Phoenix >= 1.7`](https://github.com/phoenixframework/phoenix/blob/v1.7.0/mix.exs#L73))","ref":"readme.html#features"},{"type":"extras","title":"Installation - CozyProxy","doc":"Add `:cozy_proxy` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:cozy_proxy,  }\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - CozyProxy","doc":"For more information, see the [documentation](https://hexdocs.pm/cozy_proxy/CozyProxy.html).","ref":"readme.html#usage"},{"type":"extras","title":"Thanks - CozyProxy","doc":"This library is built on the wisdom in following code:\n\n- [main_proxy](https://github.com/Main-Proxy/main_proxy)\n- [snake_proxy](https://github.com/evadne/snake/tree/master/apps/snake_proxy)\n- [master_proxy](https://github.com/wojtekmach/acme_bank/tree/master/apps/master_proxy) application inside the [acme_bank](https://github.com/wojtekmach/acme_bank) project from [wojtekmach](https://github.com/wojtekmach)\n- [master_proxy.ex](https://gist.github.com/Gazler/fe7ed5dc598250002dfe) from [Gazler](https://github.com/Gazler)","ref":"readme.html#thanks"},{"type":"extras","title":"License - CozyProxy","doc":"Apache License 2.0","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.4.0 - Changelog","doc":"Features:\n\n- add `:rewrite_path_info` backend option for controlling path rewriting\n- extend `:host` backend option for supporting regex\n- add optional `:opts` argument to `CozyProxy.start_link/_`\n\nBreaking changes:\n\n- `CozyProxy.start_link/1` doesn't call `Supervisor.start_link/3` with `[name: CozyProxy]` any more. If you need the name, you should pass it manually.","ref":"changelog.html#v0-4-0"},{"type":"extras","title":"v0.3.0 - Changelog","doc":"Features:\n\n- add adapter support\n\nBreaking changes:\n\n- change the format the options","ref":"changelog.html#v0-3-0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}